def markdown(markup):
    import markdown as md
    return md.markdown(markup)


def restructured_text(markup):
    from docutils import core
    return core.publish_parts(markup, writer_name='html')['fragment']


def textile(markup):
    import textile as tex
    return tex.textile(markup, html_type='html')



from . import HermesTestCase
from .. import models


class PostListViewTestCase(HermesTestCase):
    def url(self):
        return super(PostListViewTestCase, self).url('hermes_post_list')

    def test_context_contains_posts(self):
        """The PostListView Context should contain a QuerySet of all Posts"""
        response = self.get(self.url())
        expected = list(models.Post.objects.published())
        self.assertEqual(expected, list(response.context['posts']))


class CategoryPostListViewTestCase(HermesTestCase):
    def url(self, category):
        return category.get_absolute_url()

    def test_context_contains_posts(self):
        """The CategoryPostListView Context should contain a QuerySet of all
        Posts in the given Category
        """
        response = self.get(self.url(self.root_category))
        expected = list(models.Post.objects.filter(category=self.root_category))
        self.assertEqual(expected, list(response.context['posts']))


class ArchivePostListViewTestCase(HermesTestCase):
    def url(self, year=None, month=None, day=None):
        if year and month and day:
            url_name = 'hermes_archive_year_month_day'
            kwargs = {'year': year, 'month': month, 'day': day, }
        elif year and month:
            url_name = 'hermes_archive_year_month'
            kwargs = {'year': year, 'month': month, }
        else:
            url_name = 'hermes_archive_year'
            kwargs = {'year': year, }

        return super(ArchivePostListViewTestCase, self).url(url_name, **kwargs)

    def test_context_contains_posts_by_month_year_day(self):
        """The ArchivePostListView Context should contain a QuerySet of all
        Posts on the given month/day/year
        """
        response = self.get(self.url(year=2010, month=6, day=10))
        expected = list(models.Post.objects.created_on(year=2010, month=6, day=10))
        self.assertEqual(expected, list(response.context['posts']))

    def test_context_contains_posts_by_month_year(self):
        """The ArchivePostListView Context should contain a QuerySet of all
        Posts on the given month/day
        """
        response = self.get(self.url(year=2011, month=7))
        expected = list(models.Post.objects.created_on(year=2011, month=7))
        self.assertEqual(expected, list(response.context['posts']))

    def test_context_contains_posts_by_year(self):
        """The ArchivePostListView Context should contain a QuerySet of all
        Posts in the given year
        """
        response = self.get(self.url(year=2012))
        expected = list(models.Post.objects.created_on(year=2012))
        self.assertEqual(expected, list(response.context['posts']))


class AuthorPostListViewTestCase(HermesTestCase):
    def url(self, author):
        return super(AuthorPostListViewTestCase, self).url('hermes_author_post_list', author)

    def test_context_contains_posts(self):
        """The AuthorPoustListView Context should cotain a QuerySet af all
        Posts by the given Author.
        """
        expected = list(models.Post.objects.by('author1'))
        response = self.get(self.url('author1'))
        self.assertEqual(expected, list(response.context['posts']))


class PostDetailViewTestCase(HermesTestCase):
    def url(self, post):
        return post.get_absolute_url()

    def test_context_contains_post(self):
        response = self.get(self.url(self.post1))
        expected = self.post1
        self.assertEqual(expected, response.context['post'])



from django import test

from .. import renderers


class MarkdownRendererTestCase(test.TestCase):
    def test_render_to_html(self):
        """The Markdown Renderer should be able to translate Markdown to HTML"""
        expected = "<p><em>Markdown FTW!!</em></p>"
        self.assertEqual(expected, renderers.markdown("*Markdown FTW!!*"))


class ReStructuredTextRendererTestCase(test.TestCase):
    def test_render_to_html(self):
        """The RestructuredText Renderer should be able to translate ReStructuredText to HTML"""
        expected = "<p><em>ReStructuredText FTW!!</em></p>\n"
        self.assertEqual(expected, renderers.restructured_text("*ReStructuredText FTW!!*"))


class TextileRendererTestCase(test.TestCase):
    def test_render_to_html(self):
        """The Textile Renderer should be able to translate Textile to HTML"""
        expected = "\t<p><em>Textile</em></p>"
        self.assertEqual(expected, renderers.textile("_Textile_"))



from django.conf.urls import patterns, url

from .views import (
    ArchivePostListView,
    AuthorPostListView,
    CategoryPostListView,
    PostDetail,
    PostListView,
)
from .feeds import LatestPostFeed

urlpatterns = patterns(
    '',
    url(
        regex=r'^(?P<year>\d+)/(?P<month>\d+)/(?P<day>\d+)/(?P<slug>[\w-]+)/$',
        view=PostDetail.as_view(),
        name='hermes_post_detail',
    ),

    url(
        regex=r'^(?P<year>\d+)/(?P<month>\d+)/(?P<day>\d+)/$',
        view=ArchivePostListView.as_view(),
        name='hermes_archive_year_month_day',
    ),

    url(
        regex=r'^(?P<year>\d+)/(?P<month>\d+)/$',
        view=ArchivePostListView.as_view(),
        name='hermes_archive_year_month',
    ),

    url(
        regex=r'^(?P<year>\d+)/$',
        view=ArchivePostListView.as_view(),
        name='hermes_archive_year',
    ),

    url(
        regex=r'categories/(?P<slug>.+)/$',
        view=CategoryPostListView.as_view(),
        name='hermes_category_post_list',
    ),

    url(
        regex=r'authors/(?P<author>.+)/$',
        view=AuthorPostListView.as_view(),
        name='hermes_author_post_list',
    ),

    url(
        regex=r'^$',
        view=PostListView.as_view(),
        name='hermes_post_list',
    ),
    url(
        regex=r'^feed/$',
        view=LatestPostFeed(),
        name='hermes_post_feed'
    ),
)



from django.contrib import admin

from .models import Post, Category


class PostAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("subject", ), }


class CategoryAdmin(admin.ModelAdmin):
    include = ('title', 'parent', )
    exclude = ('slug', )

admin.site.register(Post, PostAdmin)
admin.site.register(Category, CategoryAdmin)
